==> get-package-info-0.0.3.tgz: package/lib/index.js <==
'use strict';

var Promise = require('bluebird');
var get = require('lodash.get');
var path = require('path');
var resolve = Promise.promisify(require('resolve'), {
    multiArgs: true
});

var getInfo = function getInfo(props, dir, result) {
    if (!Array.isArray(props)) return Promise.reject(new Error('First argument must be array of properties to retrieve.'));
    if (!props.length) return Promise.resolve(result);

    return resolve('package.json', {
        basedir: dir,
        moduleDirectory: '.'
    }).catch(function (err) {
        err.message += '(Properties not found yet: ' + props + ')';
        throw err;
    }).spread(function (src, pkg) {
        var nextProps = [];

        props.forEach(function (prop) {

            // For props given as array
            // Look for props in that order, and when found
            // save value under all given props
            if (Array.isArray(prop)) {
                (function () {
                    var value = void 0;
                    prop.some(function (p) {
                        return value = get(pkg, p);
                    });
                    if (value !== undefined) {
                        prop.forEach(function (p) {
                            result.values[p] = value;
                            result.source[p] = { src: src, pkg: pkg };
                        });
                    } else {
                        nextProps.push(prop);
                    }
                })();
            }

            // For regular string props, just look normally
            else {
                    var _value = get(pkg, prop);

                    if (_value !== undefined) {
                        result.values[prop] = _value;
                        result.source[prop] = { src: src, pkg: pkg };
                    } else {
                        nextProps.push(prop);
                    }
                }
        });

        // Still have props to look for, look at another package.json above this one
        if (nextProps.length) {
            return getInfo(nextProps, path.join(path.dirname(src), '..'), result);
        }

        return result;
    });
};

module.exports = function (props, dir, cb) {
    return getInfo(props, dir, { values: {}, source: {} }).nodeify(cb);
};

==> get-package-info-0.1.0.tgz: package/lib/index.js <==
'use strict';

var Promise = require('bluebird');
var get = require('lodash.get');
var path = require('path');
var resolve = Promise.promisify(require('resolve'), {
    multiArgs: true
});

var getInfo = function getInfo(props, dir, result) {
    if (!Array.isArray(props)) return Promise.reject(new Error('First argument must be array of properties to retrieve.'));
    if (!props.length) return Promise.resolve(result);

    return resolve('package.json', {
        basedir: dir,
        moduleDirectory: '.'
    }).catch(function (err) {
        err.message += '(Properties not found yet: ' + props + ')';
        throw err;
    }).spread(function (src, pkg) {
        var nextProps = [];

        props.forEach(function (prop) {

            // For props given as array
            // Look for props in that order, and when found
            // save value under all given props
            if (Array.isArray(prop)) {
                (function () {
                    var value = void 0,
                        sourceProp = void 0;
                    prop.some(function (p) {
                        sourceProp = p;
                        value = get(pkg, p);
                        return value;
                    });
                    if (value !== undefined) {
                        prop.forEach(function (p) {
                            result.values[p] = value;
                            result.source[p] = { src: src, pkg: pkg, prop: sourceProp };
                        });
                    } else {
                        nextProps.push(prop);
                    }
                })();
            }

            // For regular string props, just look normally
            else {
                    var _value = get(pkg, prop);

                    if (_value !== undefined) {
                        result.values[prop] = _value;
                        result.source[prop] = { src: src, pkg: pkg, prop: prop };
                    } else {
                        nextProps.push(prop);
                    }
                }
        });

        // Still have props to look for, look at another package.json above this one
        if (nextProps.length) {
            return getInfo(nextProps, path.join(path.dirname(src), '..'), result);
        }

        return result;
    });
};

module.exports = function (props, dir, cb) {
    return getInfo(props, dir, { values: {}, source: {} }).nodeify(cb);
};
